@@ -32,7 +32,7 @@ class CreatorCoin:
             account_provider = FactoryUserAccount()
         self.account = account_provider
 
-    def create_coin(self, account_id: str):
+    def create_coin(self, account_id: str, initial_contract_balance=CONTRACT_INITIAL_BALANCE):
         """Takes `account_id` is without the domain, eg:
         instead of `myname.near` account_id == `myname` and
         deploy a creator coin on the account.
@@ -53,7 +53,7 @@ class CreatorCoin:
             method,
             args,  # type: ignore
             gas=CONTRACT_ATTACHED_GAS,
-            amount=CONTRACT_INITIAL_BALANCE)  # type: ignore
+            amount=initial_contract_balance)  # type: ignore
         return res
 
     def buy_token(self, account_id: str, amount: int, contract_id: str):
