@@ -2,6 +2,7 @@ import unittest
 
 from loozr_near_sdk.account import AccountHelper
 from loozr_near_sdk.utils.constants import ACCOUNT_INIT_BALANCE
+from loozr_near_sdk.utils.base import LZR_MIXER_ACCOUNT_ID
 
 
 class AccountHelperTest(unittest.TestCase):
@@ -22,4 +23,4 @@ class AccountHelperTest(unittest.TestCase):
     def test_account_id_by_name(self) -> None:
         account_name = 'test_user'
         account_id = self.account_helper.get_account_id_from_name(account_name)
-        self.assertEqual(account_id, 'test_user.lzr2_mixr.test.near')
+        self.assertEqual(account_id, f'test_user.{LZR_MIXER_ACCOUNT_ID}')
